package ru.dbotthepony.mc.otm.capability

import java.util.function.Predicate

/**
 * Represents possible flow direction, both for matter and for energy
 */
enum class FlowDirection(val input: Boolean, val output: Boolean) : Predicate<FlowDirection> {
	/**
	 * Can only be inputted (consumer)
	 */
	INPUT(true, false),

	/**
	 * Can only be outputted/transmitted (producer)
	 */
	OUTPUT(false, true),

	/**
	 * Can both consume and produce (capacitor)
	 */
	BI_DIRECTIONAL(true, true),

	/**
	 * Why would you want to use this
	 */
	NONE(false, false);

	override fun test(t: FlowDirection): Boolean {
		return t === this || (!input || t.input) && (!output || t.output)
	}
}
